@@ -36,7 +36,7 @@ static const unsigned long _glibtop_sysdeps_loadavg_tasks =
 /* Init function. */
 
 void
-glibtop_init_loadavg_s (glibtop *server)
+_glibtop_init_loadavg_s (glibtop *server)
 {
 	server->sysdeps.loadavg = _glibtop_sysdeps_loadavg;
 }
@@ -50,8 +50,6 @@ glibtop_get_loadavg_s (glibtop *server, glibtop_loadavg *buf)
 {
 	char buffer [BUFSIZ], *p, *old;
 
-	glibtop_init_s (&server, GLIBTOP_SYSDEPS_LOADAVG, 0);
-
 	memset (buf, 0, sizeof (glibtop_loadavg));
 
 	file_to_buffer(server, buffer, FILENAME);
