@@ -1,5 +1,3 @@
-/* $Id: proclist.c 2422 2005-12-12 09:38:15Z jamesh $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -42,7 +40,7 @@ static const unsigned long _glibtop_sysdeps_proclist =
 /* Init function. */
 
 void
-glibtop_init_proclist_s (glibtop *server)
+_glibtop_init_proclist_s (glibtop *server)
 {
 	server->sysdeps.proclist = _glibtop_sysdeps_proclist;
 }
